/*
* Copyright © 2010 Red Hat, Inc.
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
*
*           http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*/

package com.redhat.rhevm.api.powershell.enums;

import java.util.HashMap;

import com.redhat.rhevm.api.model.StorageDomainStatus;

public enum PowerShellStorageDomainStatus {
    Unknown(0), Uninitialized(1), Unattached(2), Active(3), InActive(4), Locked(5);

    private static HashMap<Integer, PowerShellStorageDomainStatus> mapping;
    static {
        mapping = new HashMap<Integer, PowerShellStorageDomainStatus>();
        for (PowerShellStorageDomainStatus value : values()) {
            mapping.put(value.value, value);
        }
    }

    private int value;

    private PowerShellStorageDomainStatus(int value) {
        this.value = value;
    }

    public int getValue() {
        return value;
    }

    public StorageDomainStatus map() {
        switch (this) {
        case Unattached:
            return StorageDomainStatus.UNATTACHED;
        case Active:
            return StorageDomainStatus.ACTIVE;
        case InActive:
            return StorageDomainStatus.INACTIVE;
        case Locked:
            return StorageDomainStatus.LOCKED;
        case Unknown:
            return StorageDomainStatus.UNKNOWN;
        default:
            assert false : null;
            return null;
        }
    }

    public static PowerShellStorageDomainStatus forValue(int value) {
        return mapping.get(value);
    }
}
