/*
* Copyright © 2010 Red Hat, Inc.
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
*
*           http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*/

package com.redhat.rhevm.api.powershell.model;

import java.util.ArrayList;
import java.util.List;

import com.redhat.rhevm.api.model.Network;
import com.redhat.rhevm.api.model.MAC;
import com.redhat.rhevm.api.model.NIC;
import com.redhat.rhevm.api.model.VM;
import com.redhat.rhevm.api.powershell.enums.PowerShellVmInterfaceType;
import com.redhat.rhevm.api.powershell.util.PowerShellParser;

public class PowerShellNIC {

    private static final String NICS_TYPE = "RhevmCmd.CLIVmNetworkAdapter";

    static boolean isNIC(PowerShellParser.Entity entity) {
        return NICS_TYPE.equals(entity.getType());
    }

    public static List<NIC> parse(PowerShellParser parser, String vmId, String output) {
        List<NIC> ret = new ArrayList<NIC>();

        for (PowerShellParser.Entity entity : parser.parse(output)) {
            ret.add(parseEntity(vmId, entity));
        }
        return ret;
    }

    public static NIC parseEntity(String vmId, PowerShellParser.Entity entity){
        NIC nic = new NIC();

        nic.setId(entity.get("id"));
        nic.setName(entity.get("name"));

        nic.setVm(new VM());
        nic.getVm().setId(vmId);

        Network network = new Network();
        network.setName(entity.get("network"));
        nic.setNetwork(network);

        nic.setInterface(PowerShellVmInterfaceType.valueOf(entity.get("type")).map().value());

        MAC mac = new MAC();
        mac.setAddress(entity.get("macaddress"));
        nic.setMac(mac);

        return nic;
    }
}
