/*
* Copyright © 2010 Red Hat, Inc.
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
*
*           http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*/

package com.redhat.rhevm.api.powershell.resource;

import java.util.concurrent.Executor;

import javax.ws.rs.core.HttpHeaders;

import com.redhat.rhevm.api.common.resource.AbstractActionableResource;
import com.redhat.rhevm.api.common.resource.UriInfoProvider;
import com.redhat.rhevm.api.model.BaseResource;
import com.redhat.rhevm.api.powershell.util.PowerShellParser;
import com.redhat.rhevm.api.powershell.util.PowerShellPool;
import com.redhat.rhevm.api.powershell.util.PowerShellPoolMap;

public abstract class AbstractPowerShellActionableResource<R extends BaseResource> extends AbstractActionableResource<R> {

    protected PowerShellPoolMap shellPools;
    protected PowerShellParser parser;
    protected HttpHeaders httpHeaders;

    public AbstractPowerShellActionableResource(String id , PowerShellPoolMap shellPools) {
        super(id);
        this.shellPools = shellPools;
    }

    public AbstractPowerShellActionableResource(String id, Executor executor, PowerShellPoolMap shellPools) {
        super(id, executor);
        this.shellPools = shellPools;
    }

    public AbstractPowerShellActionableResource(String id, Executor executor, UriInfoProvider uriProvider, PowerShellPoolMap shellPools) {
        super(id, executor, uriProvider);
        this.shellPools = shellPools;
    }

    public AbstractPowerShellActionableResource(String id,
                                                Executor executor,
                                                PowerShellPoolMap shellPools,
                                                PowerShellParser parser) {
        super(id, executor);
        this.shellPools = shellPools;
        this.parser = parser;
    }

    public AbstractPowerShellActionableResource(String id,
                                                Executor executor,
                                                UriInfoProvider uriProvider,
                                                PowerShellPoolMap shellPools,
                                                PowerShellParser parser) {
        super(id, executor, uriProvider);
        this.shellPools = shellPools;
        this.parser = parser;
    }

    protected PowerShellPool getPool() {
        return shellPools.get();
    }

    protected PowerShellPoolMap getShellPools() {
        return shellPools;
    }

    protected PowerShellParser getParser() {
        return parser;
    }

    public HttpHeaders getHttpHeaders() {
        return httpHeaders;
    }

    public void setHttpHeaders(HttpHeaders httpHeaders) {
        this.httpHeaders = httpHeaders;
    }

}
