/*
* Copyright © 2010 Red Hat, Inc.
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
*
*           http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*/

package com.redhat.rhevm.api.powershell.resource;

import javax.ws.rs.core.Response;
import javax.ws.rs.core.UriBuilder;

import com.redhat.rhevm.api.common.resource.UriInfoProvider;
import com.redhat.rhevm.api.model.CdRom;
import com.redhat.rhevm.api.model.CdRoms;
import com.redhat.rhevm.api.powershell.util.PowerShellCmd;
import com.redhat.rhevm.api.powershell.util.PowerShellPoolMap;
import com.redhat.rhevm.api.powershell.util.PowerShellUtils;
import com.redhat.rhevm.api.resource.DevicesResource;

import static com.redhat.rhevm.api.common.util.CompletenessAssertor.validateParameters;


public class PowerShellCdRomsResource
    extends PowerShellReadOnlyCdRomsResource
    implements DevicesResource<CdRom, CdRoms> {

    private static final String CDROM_ID = Integer.toString("cdrom".hashCode());

    public PowerShellCdRomsResource(String parentId, PowerShellPoolMap shellPools, CdRomQuery query, UriInfoProvider uriProvider) {
        super(parentId, shellPools, query, uriProvider);
    }

    CdRom updateCdRom(String cdIsoPath) {
        StringBuilder buf = new StringBuilder();

        buf.append("$v = get-vm " + PowerShellUtils.escape(parentId) + ";");
        buf.append("$v.cdisopath = " + PowerShellUtils.escape(cdIsoPath) + ";");
        buf.append("try {");
        buf.append("mount-disk -vmobject $v -isofilename " + PowerShellUtils.escape(cdIsoPath) + ";");
        buf.append("} catch {");
        buf.append("update-vm -vmobject $v;");
        buf.append("}");

        PowerShellCmd.runCommand(getPool(), buf.toString());
        return buildCdRom(cdIsoPath);
    }

    @Override
    public Response add(CdRom cdrom) {
        validateParameters(cdrom, "file");
        String cdIsoPath = cdrom.getFile().getId();

        updateCdRom(cdIsoPath);

        cdrom = buildCdRom(cdIsoPath);

        UriBuilder uriBuilder = getUriInfo().getAbsolutePathBuilder().path(cdrom.getId());

        return Response.created(uriBuilder.build()).entity(cdrom).build();
    }

    @Override
    public void remove(String id) {
        if (id.equals(CDROM_ID)) {
            updateCdRom("");
        }
    }

    @Override
    public PowerShellDeviceResource<CdRom, CdRoms> getDeviceSubResource(String id) {
        return new PowerShellCdRomDeviceResource(this, id);
    }
}
