/*
* Copyright © 2010 Red Hat, Inc.
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
*
*           http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*/

package com.redhat.rhevm.api.powershell.resource;

import java.util.List;
import java.util.concurrent.Executor;

import com.redhat.rhevm.api.common.util.LinkHelper;
import com.redhat.rhevm.api.model.Domain;
import com.redhat.rhevm.api.model.Group;
import com.redhat.rhevm.api.model.Groups;
import com.redhat.rhevm.api.powershell.model.PowerShellGroup;
import com.redhat.rhevm.api.powershell.util.PowerShellCmd;
import com.redhat.rhevm.api.powershell.util.PowerShellParser;
import com.redhat.rhevm.api.powershell.util.PowerShellPoolMap;
import com.redhat.rhevm.api.powershell.util.PowerShellUtils;
import com.redhat.rhevm.api.resource.DomainGroupResource;
import com.redhat.rhevm.api.resource.DomainGroupsResource;

public class PowerShellDomainGroupsResource extends InjectableUriProviderBase implements DomainGroupsResource {

    private PowerShellDomainResource parent;

    public PowerShellDomainGroupsResource(PowerShellDomainResource parent,
                                          Executor executor,
                                          PowerShellPoolMap shellPools,
                                          PowerShellParser parser) {
        super(executor, shellPools, parser);
        this.parent = parent;
    }

    public String getDomainName() {
        return parent.getId();
    }

    @Override
    public Groups list() {
        StringBuilder buf = new StringBuilder();

        buf.append("select-user -ad ");
        buf.append("-domain " + PowerShellUtils.escape(getDomainName()));
        buf.append(" | ? ");
        buf.append("{ $_.isgroup() }");

        Groups ret = new Groups();
        for (Group group : runAndParse(buf.toString())) {
            ret.getGroups().add(addLinks(group));
        }
        return ret;
    }

    @Override
    public DomainGroupResource getDomainGroupSubResource(String id) {
        return new PowerShellDomainGroupResource(this, id);
    }

    protected List<Group> runAndParse(String command) {
        return PowerShellGroup.parse(getParser(), PowerShellCmd.runCommand(getPool(), command));
    }

    public Group runAndParseSingle(String command) {
        List<Group> groups = runAndParse(command);
        return !groups.isEmpty() ? groups.get(0) : null;
    }

    public Group addLinks(Group group) {
        group.setDomain(new Domain());
        group.getDomain().setId(parent.getId());

        group.getLinks().clear();
        return LinkHelper.addLinks(getUriInfo(), group);
    }
}
